@@ -20,7 +20,7 @@ class Command(BaseCommand):
         #     except Poll.DoesNotExist:
         #         raise CommandError('Poll "%s" does not exist' % poll_id)
 
-        users = User.objects.filter(is_superuser=False)
+        users = User.objects.filter(is_staff=False, is_superuser=False)
         users_count = users.count()
         updated_users = 0
 
