@@ -11,6 +11,7 @@ from allauth.utils import get_user_model
 
 from .apps.emails.models import EmailAddress
 from .apps.services.models import Service
+from .apps.groups.models import Group
 
 from .utils import is_test_user
 from . import app_settings
@@ -51,12 +52,14 @@ class LoginForm(allauth_LoginForm):
 class BaseSignupForm(allauth_SignupForm):
     fingerprint = CharField(label='fingerprint', max_length=255, required=False, widget=HiddenInput(),
                             initial='undefined')
-    referrer = CharField(label='referrer', max_length=255, required=False, widget=HiddenInput(),
+
+    referer = CharField(label='referer', max_length=255, required=False, widget=HiddenInput(),
                         initial=app_settings.APP_URL)
 
+    groups = CharField(label='groups', required=False)
+
     field_order = SIGNUP_FORM_FIELDS
 
-    # pai
     def __init__(self, *args, **kwargs):
         super(BaseSignupForm, self).__init__(*args, **kwargs)
 
@@ -71,20 +74,23 @@ class BaseSignupForm(allauth_SignupForm):
         return kwargs
 
     def save(self, request):
-        # test_mode check
+
         new_user = super(BaseSignupForm, self).save(request)
+
+        # test_mode check
         test_mode = request.GET.get('test_mode', None)
+
         adapter = get_adapter(request)
 
-        username = self.cleaned_data["username"]
-        email = self.cleaned_data["email"]
-        fingerprint = self.cleaned_data["fingerprint"]
-        referrer = self.cleaned_data["referrer"]
+        username = self.cleaned_data.get("username", None)
+        email = self.cleaned_data.get("email", None)
+        fingerprint = self.cleaned_data.get("fingerprint", None)
+        referer = self.cleaned_data["referer"]
+        groups = self.cleaned_data.get("groups", '')
+        user_model = get_user_model()
 
         try:
-
             if test_mode is None and username == app_settings.TEST_USER_USERNAME:
-                user_model = get_user_model()
                 username_field = allauth_app_settings.USER_MODEL_USERNAME_FIELD
 
                 self.add_error(allauth_app_settings.USER_MODEL_USERNAME_FIELD, adapter.error_messages['username_taken'])
@@ -98,8 +104,6 @@ class BaseSignupForm(allauth_SignupForm):
                 )
 
             if test_mode is None and email == app_settings.TEST_USER_EMAIL:
-                user_model = get_user_model()
-
                 self.add_error('email', adapter.error_messages['email_taken'])
 
                 raise forms.ValidationError(
@@ -116,15 +120,25 @@ class BaseSignupForm(allauth_SignupForm):
 
                 adapter.confirm_email(request, EmailAddress.objects.get(email=new_user.email))
 
-            # service subscription by "referrer" field
             if new_user is not None:
-                if referrer not in [app_settings.APP_URL, '', None]:
-                    logger.info('Subscripting new user to service with url "{}"'.format(referrer))
+                # service subscription by "referer" field
+                if referer not in [app_settings.APP_URL, '', None]:
+                    logger.info('Subscripting new user to service with url "{}"'.format(referer))
 
-                    service = Service.objects.filter(service_url=referrer).first()
+                    service = Service.objects.filter(service_url=referer).first()
                     if service is not None:
                         adapter.subscribe_profile_to_service(new_user.sso_app_profile, service)
 
+                # subscribing user to groups
+                if len(groups):
+                    group_names = groups.split(',')
+                    logger.info('Subscripting new user to groups "{}"'.format(group_names))
+                    for g in group_names:
+                        group = Group.objects.filter(name=g).first()
+                        if group is not None:
+                            new_user.sso_app_profile.groups.add(group)
+
+
         # delete creating user model if any exception occurred
         except Exception as e:
             logger.exception('Error subscribing new user "{}"'.format(e))
@@ -151,6 +165,7 @@ if app_settings.BACKEND_SIGNUP_MUST_FILL_PROFILE:
         address = CharField(required='address' in app_settings.REQUIRED_PROFILE_FIELDS)
         # business_address = CharField(required='business_address' in app_settings.REQUIRED_PROFILE_FIELDS)
         language = CharField(required='language' in app_settings.REQUIRED_PROFILE_FIELDS)
+        alias = CharField(required='alias' in app_settings.REQUIRED_PROFILE_FIELDS)
 
 else:
     class SignupForm(BaseSignupForm):
